Class: Aws::Translate::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Translate::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-translate/client.rb,
sig/client.rbs
Overview
An API client for Translate. To construct a client, you need to configure a :region and :credentials.
client = Aws::Translate::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateParallelDataResponseSuccess, _DeleteParallelDataResponseSuccess, _DescribeTextTranslationJobResponseSuccess, _GetParallelDataResponseSuccess, _GetTerminologyResponseSuccess, _ImportTerminologyResponseSuccess, _ListLanguagesResponseSuccess, _ListParallelDataResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTerminologiesResponseSuccess, _ListTextTranslationJobsResponseSuccess, _StartTextTranslationJobResponseSuccess, _StopTextTranslationJobResponseSuccess, _TagResourceResponseSuccess, _TranslateDocumentResponseSuccess, _TranslateTextResponseSuccess, _UntagResourceResponseSuccess, _UpdateParallelDataResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_parallel_data(params = {}) ⇒ Types::CreateParallelDataResponse
Creates a parallel data resource in Amazon Translate by importing an input file from Amazon S3.
-
#delete_parallel_data(params = {}) ⇒ Types::DeleteParallelDataResponse
Deletes a parallel data resource in Amazon Translate.
-
#delete_terminology(params = {}) ⇒ Struct
A synchronous action that deletes a custom terminology.
-
#describe_text_translation_job(params = {}) ⇒ Types::DescribeTextTranslationJobResponse
Gets the properties associated with an asynchronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on.
-
#get_parallel_data(params = {}) ⇒ Types::GetParallelDataResponse
Provides information about a parallel data resource.
-
#get_terminology(params = {}) ⇒ Types::GetTerminologyResponse
Retrieves a custom terminology.
-
#import_terminology(params = {}) ⇒ Types::ImportTerminologyResponse
Creates or updates a custom terminology, depending on whether one already exists for the given terminology name.
-
#list_languages(params = {}) ⇒ Types::ListLanguagesResponse
Provides a list of languages (RFC-5646 codes and names) that Amazon Translate supports.
-
#list_parallel_data(params = {}) ⇒ Types::ListParallelDataResponse
Provides a list of your parallel data resources in Amazon Translate.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a given Amazon Translate resource.
-
#list_terminologies(params = {}) ⇒ Types::ListTerminologiesResponse
Provides a list of custom terminologies associated with your account.
-
#list_text_translation_jobs(params = {}) ⇒ Types::ListTextTranslationJobsResponse
Gets a list of the batch translation jobs that you have submitted.
-
#start_text_translation_job(params = {}) ⇒ Types::StartTextTranslationJobResponse
Starts an asynchronous batch translation job.
-
#stop_text_translation_job(params = {}) ⇒ Types::StopTextTranslationJobResponse
Stops an asynchronous batch translation job that is in progress.
-
#tag_resource(params = {}) ⇒ Struct
Associates a specific tag with a resource.
-
#translate_document(params = {}) ⇒ Types::TranslateDocumentResponse
Translates the input document from the source language to the target language.
-
#translate_text(params = {}) ⇒ Types::TranslateTextResponse
Translates input text from the source language to the target language.
-
#untag_resource(params = {}) ⇒ Struct
Removes a specific tag associated with an Amazon Translate resource.
-
#update_parallel_data(params = {}) ⇒ Types::UpdateParallelDataResponse
Updates a previously created parallel data resource by importing a new input file from Amazon S3.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-translate/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1762 1763 1764 |
# File 'lib/aws-sdk-translate/client.rb', line 1762 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1765 1766 1767 |
# File 'lib/aws-sdk-translate/client.rb', line 1765 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 |
# File 'lib/aws-sdk-translate/client.rb', line 1735 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Translate') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-translate' context[:gem_version] = '1.99.0' Seahorse::Client::Request.new(handlers, context) end |
#create_parallel_data(params = {}) ⇒ Types::CreateParallelDataResponse
Creates a parallel data resource in Amazon Translate by importing an input file from Amazon S3. Parallel data files contain examples that show how you want segments of text to be translated. By adding parallel data, you can influence the style, tone, and word choice in your translation output.
88 |
# File 'sig/client.rbs', line 88
def create_parallel_data: (
|
#delete_parallel_data(params = {}) ⇒ Types::DeleteParallelDataResponse
Deletes a parallel data resource in Amazon Translate.
115 |
# File 'sig/client.rbs', line 115
def delete_parallel_data: (
|
#delete_terminology(params = {}) ⇒ Struct
A synchronous action that deletes a custom terminology.
121 |
# File 'sig/client.rbs', line 121
def delete_terminology: (
|
#describe_text_translation_job(params = {}) ⇒ Types::DescribeTextTranslationJobResponse
Gets the properties associated with an asynchronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on.
131 |
# File 'sig/client.rbs', line 131
def describe_text_translation_job: (
|
#get_parallel_data(params = {}) ⇒ Types::GetParallelDataResponse
Provides information about a parallel data resource.
144 |
# File 'sig/client.rbs', line 144
def get_parallel_data: (
|
#get_terminology(params = {}) ⇒ Types::GetTerminologyResponse
Retrieves a custom terminology.
156 |
# File 'sig/client.rbs', line 156
def get_terminology: (
|
#import_terminology(params = {}) ⇒ Types::ImportTerminologyResponse
Creates or updates a custom terminology, depending on whether one already exists for the given terminology name. Importing a terminology with the same name as an existing one will merge the terminologies based on the chosen merge strategy. The only supported merge strategy is OVERWRITE, where the imported terminology overwrites the existing terminology of the same name.
If you import a terminology that overwrites an existing one, the new terminology takes up to 10 minutes to fully propagate. After that, translations have access to the new terminology.
168 |
# File 'sig/client.rbs', line 168
def import_terminology: (
|
#list_languages(params = {}) ⇒ Types::ListLanguagesResponse
Provides a list of languages (RFC-5646 codes and names) that Amazon Translate supports.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
197 |
# File 'sig/client.rbs', line 197
def list_languages: (
|
#list_parallel_data(params = {}) ⇒ Types::ListParallelDataResponse
Provides a list of your parallel data resources in Amazon Translate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
210 |
# File 'sig/client.rbs', line 210
def list_parallel_data: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a given Amazon Translate resource. For more information, see Tagging your resources.
221 |
# File 'sig/client.rbs', line 221
def list_tags_for_resource: (
|
#list_terminologies(params = {}) ⇒ Types::ListTerminologiesResponse
Provides a list of custom terminologies associated with your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
232 |
# File 'sig/client.rbs', line 232
def list_terminologies: (
|
#list_text_translation_jobs(params = {}) ⇒ Types::ListTextTranslationJobsResponse
Gets a list of the batch translation jobs that you have submitted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
244 |
# File 'sig/client.rbs', line 244
def list_text_translation_jobs: (
|
#start_text_translation_job(params = {}) ⇒ Types::StartTextTranslationJobResponse
Starts an asynchronous batch translation job. Use batch translation
jobs to translate large volumes of text across multiple documents at
once. For batch translation, you can input documents with different
source languages (specify auto as the source language). You can
specify one or more target languages. Batch translation translates
each input document into each of the target languages. For more
information, see Asynchronous batch processing.
Batch translation jobs can be described with the DescribeTextTranslationJob operation, listed with the ListTextTranslationJobs operation, and stopped with the StopTextTranslationJob operation.
262 |
# File 'sig/client.rbs', line 262
def start_text_translation_job: (
|
#stop_text_translation_job(params = {}) ⇒ Types::StopTextTranslationJobResponse
Stops an asynchronous batch translation job that is in progress.
If the job's state is IN_PROGRESS, the job will be marked for
termination and put into the STOP_REQUESTED state. If the job
completes before it can be stopped, it is put into the COMPLETED
state. Otherwise, the job is put into the STOPPED state.
Asynchronous batch translation jobs are started with the
StartTextTranslationJob operation. You can use the
DescribeTextTranslationJob or ListTextTranslationJobs operations to
get a batch translation job's JobId.
295 |
# File 'sig/client.rbs', line 295
def stop_text_translation_job: (
|
#tag_resource(params = {}) ⇒ Struct
Associates a specific tag with a resource. A tag is a key-value pair that adds as a metadata to a resource. For more information, see Tagging your resources.
304 |
# File 'sig/client.rbs', line 304
def tag_resource: (
|
#translate_document(params = {}) ⇒ Types::TranslateDocumentResponse
Translates the input document from the source language to the target
language. This synchronous operation supports text, HTML, or Word
documents as the input document. TranslateDocument supports
translations from English to any supported language, and from any
supported language to English. Therefore, specify either the source
language code or the target language code as “en” (English).
If you set the Formality parameter, the request will fail if the
target language does not support formality. For a list of target
languages that support formality, see Setting formality.
324 |
# File 'sig/client.rbs', line 324
def translate_document: (
|
#translate_text(params = {}) ⇒ Types::TranslateTextResponse
Translates input text from the source language to the target language. For a list of available languages and language codes, see Supported languages.
349 |
# File 'sig/client.rbs', line 349
def translate_text: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a specific tag associated with an Amazon Translate resource. For more information, see Tagging your resources.
366 |
# File 'sig/client.rbs', line 366
def untag_resource: (
|
#update_parallel_data(params = {}) ⇒ Types::UpdateParallelDataResponse
Updates a previously created parallel data resource by importing a new input file from Amazon S3.
380 |
# File 'sig/client.rbs', line 380
def update_parallel_data: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1755 1756 1757 |
# File 'lib/aws-sdk-translate/client.rb', line 1755 def waiter_names [] end |