Class: Aws::Translate::Types::GetParallelDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-translate/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auxiliary_data_locationTypes::ParallelDataDataLocation

The Amazon S3 location of a file that provides any errors or warnings that were produced by your input file. This file was created when Amazon Translate attempted to create a parallel data resource. The location is returned as a presigned URL to that has a 30-minute expiration.

Returns:



337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-translate/types.rb', line 337

class GetParallelDataResponse < Struct.new(
  :parallel_data_properties,
  :data_location,
  :auxiliary_data_location,
  :latest_update_attempt_auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end

#data_locationTypes::ParallelDataDataLocation

The Amazon S3 location of the most recent parallel data input file that was successfully imported into Amazon Translate. The location is returned as a presigned URL that has a 30-minute expiration.

Amazon Translate doesn't scan all input files for the risk of CSV injection attacks.

CSV injection occurs when a .csv or .tsv file is altered so that a record contains malicious code. The record begins with a special character, such as =, +, -, or @. When the file is opened in a spreadsheet program, the program might interpret the record as a formula and run the code within it.

Before you download an input file from Amazon S3, ensure that you recognize the file and trust its creator.

Returns:



337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-translate/types.rb', line 337

class GetParallelDataResponse < Struct.new(
  :parallel_data_properties,
  :data_location,
  :auxiliary_data_location,
  :latest_update_attempt_auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end

#latest_update_attempt_auxiliary_data_locationTypes::ParallelDataDataLocation

The Amazon S3 location of a file that provides any errors or warnings that were produced by your input file. This file was created when Amazon Translate attempted to update a parallel data resource. The location is returned as a presigned URL to that has a 30-minute expiration.

Returns:



337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-translate/types.rb', line 337

class GetParallelDataResponse < Struct.new(
  :parallel_data_properties,
  :data_location,
  :auxiliary_data_location,
  :latest_update_attempt_auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end

#parallel_data_propertiesTypes::ParallelDataProperties

The properties of the parallel data resource that is being retrieved.

Returns:



337
338
339
340
341
342
343
344
# File 'lib/aws-sdk-translate/types.rb', line 337

class GetParallelDataResponse < Struct.new(
  :parallel_data_properties,
  :data_location,
  :auxiliary_data_location,
  :latest_update_attempt_auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end