Class: Aws::Translate::Types::GetTerminologyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-translate/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auxiliary_data_locationTypes::TerminologyDataLocation

The Amazon S3 location of a file that provides any errors or warnings that were produced by your input file. This file was created when Amazon Translate attempted to create a terminology resource. The location is returned as a presigned URL to that has a 30-minute expiration.

Returns:



405
406
407
408
409
410
411
# File 'lib/aws-sdk-translate/types.rb', line 405

class GetTerminologyResponse < Struct.new(
  :terminology_properties,
  :terminology_data_location,
  :auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end

#terminology_data_locationTypes::TerminologyDataLocation

The Amazon S3 location of the most recent custom terminology input file that was successfully imported into Amazon Translate. The location is returned as a presigned URL that has a 30-minute expiration.

Amazon Translate doesn’t scan all input files for the risk of CSV injection attacks.

CSV injection occurs when a .csv or .tsv file is altered so that a

record contains malicious code. The record begins with a special character, such as =, +, -, or @. When the file is opened in a spreadsheet program, the program might interpret the record as a formula and run the code within it.

Before you download an input file from Amazon S3, ensure that you

recognize the file and trust its creator.

Returns:



405
406
407
408
409
410
411
# File 'lib/aws-sdk-translate/types.rb', line 405

class GetTerminologyResponse < Struct.new(
  :terminology_properties,
  :terminology_data_location,
  :auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end

#terminology_propertiesTypes::TerminologyProperties

The properties of the custom terminology being retrieved.

Returns:



405
406
407
408
409
410
411
# File 'lib/aws-sdk-translate/types.rb', line 405

class GetTerminologyResponse < Struct.new(
  :terminology_properties,
  :terminology_data_location,
  :auxiliary_data_location)
  SENSITIVE = []
  include Aws::Structure
end