Class: Aws::Translate::Types::UpdateParallelDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-translate/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#latest_update_attempt_atTime

The time that the most recent update was attempted.



2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-translate/types.rb', line 2149

class UpdateParallelDataResponse < Struct.new(
  :name,
  :status,
  :latest_update_attempt_status,
  :latest_update_attempt_at)
  SENSITIVE = []
  include Aws::Structure
end

#latest_update_attempt_statusString

The status of the parallel data update attempt. When the updated parallel data resource is ready for you to use, the status is ACTIVE.



2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-translate/types.rb', line 2149

class UpdateParallelDataResponse < Struct.new(
  :name,
  :status,
  :latest_update_attempt_status,
  :latest_update_attempt_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the parallel data resource being updated.



2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-translate/types.rb', line 2149

class UpdateParallelDataResponse < Struct.new(
  :name,
  :status,
  :latest_update_attempt_status,
  :latest_update_attempt_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the parallel data resource that you are attempting to update. Your update request is accepted only if this status is either ACTIVE or FAILED.



2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-translate/types.rb', line 2149

class UpdateParallelDataResponse < Struct.new(
  :name,
  :status,
  :latest_update_attempt_status,
  :latest_update_attempt_at)
  SENSITIVE = []
  include Aws::Structure
end